@@ -1,3 +1,5 @@
+from pandas import DataFrame
+
 from wikirate4py.exceptions import WikiRate4PyException
 from wikirate4py.mixins import WikiRateEntity
 import html2text
@@ -11,7 +13,7 @@ class Company(WikiRateEntity):
         self.raw = data
         if data["type"]["id"] != 651:
             raise WikiRate4PyException('Invalid type of entity')
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.headquarters = None
         if data.get("headquarters").get("content") is not None:
@@ -32,7 +34,7 @@ class CompanyItem(WikiRateEntity):
         self.raw = data
         if data["type"] != "Company":
             raise WikiRate4PyException('Invalid type of entity')
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.headquarters = data.get("headquarters")
         self.aliases = data.get("alias")
@@ -51,7 +53,7 @@ class Topic(WikiRateEntity):
         if data["type"]["id"] != 1010:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.metrics = data.get("metrics", 0)
         self.projects = data.get("projects", 0)
@@ -67,7 +69,7 @@ class Project(WikiRateEntity):
         if data["type"]["id"] != 39830:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.metrics = data.get("metrics", {}).get("content", [])
         self.companies = data.get("companies", {}).get("content", [])
@@ -76,6 +78,12 @@ class Project(WikiRateEntity):
         self.updated_at = data.get("updated_at")
         self.url = data.get("html_url")
 
+    def to_dataframe(self):
+        answers = []
+        for answer in self.answers:
+            answers.append(answer.json())
+        return DataFrame.from_dict(answers)
+
 
 class ProjectItem(WikiRateEntity):
     __slots__ = ("id", "name", "url", "raw")
@@ -85,7 +93,45 @@ class ProjectItem(WikiRateEntity):
         if data["type"] != 'Project':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
+        self.name = data["name"]
+        self.url = data.get("url").replace(".json", "")
+
+
+class Dataset(WikiRateEntity):
+    __slots__ = ("id", "name", "metrics", "companies", "answers", "license", "created_at", "updated_at", "url", "raw")
+
+    def __init__(self, data):
+        self.raw = data
+        if data["type"]["id"] != 7926098:
+            raise WikiRate4PyException('Invalid type of entity')
+
+        self.id = data.get("id")
+        self.name = data["name"]
+        self.metrics = data.get("metrics", {}).get("content", [])
+        self.companies = data.get("companies", {}).get("content", [])
+        self.answers = [AnswerItem(item) for item in data.get("items", {})]
+        self.license = data.get("license")
+        self.created_at = data.get("created_at")
+        self.updated_at = data.get("updated_at")
+        self.url = data.get("html_url")
+
+    def to_dataframe(self):
+        answers = []
+        for answer in self.answers:
+            answers.append(answer.json())
+        return DataFrame.from_dict(answers)
+
+
+class DatasetItem(WikiRateEntity):
+    __slots__ = ("id", "name", "url", "raw")
+
+    def __init__(self, data):
+        self.raw = data
+        if data["type"] != 'Data Set':
+            raise WikiRate4PyException('Invalid type of entity')
+
+        self.id = data.get("id")
         self.name = data["name"]
         self.url = data.get("url").replace(".json", "")
 
@@ -98,7 +144,7 @@ class TopicItem(WikiRateEntity):
         if data["type"] != 'Topic':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.metrics = data.get("metrics", 0)
         self.projects = data.get("projects", 0)
@@ -118,7 +164,7 @@ class Metric(WikiRateEntity):
             raise WikiRate4PyException('Invalid type of entity')
         h = html2text.HTML2Text()
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.designer = data["designer"]
         self.name = data["title"]
         self.question = data.get("question", {}).get("content")
@@ -158,7 +204,7 @@ class MetricItem(WikiRateEntity):
             raise WikiRate4PyException('Invalid type of entity')
         h = html2text.HTML2Text()
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.designer = data["designer"]
         self.name = data["title"]
         self.question = data.get("question")
@@ -197,7 +243,7 @@ class ResearchGroup(WikiRateEntity):
         if data["type"]["id"] != 2301582:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.url = data.get("html_url")
 
@@ -211,7 +257,7 @@ class ResearchGroupItem(WikiRateEntity):
         if data["type"] != 'Research Group':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.url = data.get("url").replace(".json", "")
 
@@ -225,7 +271,7 @@ class CompanyGroup(WikiRateEntity):
         if data["type"]["id"] != 5458825:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.members = data.get("companies", {}).get("content", [])
         self.members_links = data["links"]
@@ -241,7 +287,7 @@ class CompanyGroupItem(WikiRateEntity):
         if data["type"] != 'Company Group':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data["name"]
         self.members = data.get("companies", [])
         self.url = data.get("url").replace('.json', '')
@@ -257,7 +303,7 @@ class Source(WikiRateEntity):
         if data.get("type").get("id") != 629:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data.get("name")
         self.title = data.get("title", {}).get("content")
         self.description = data.get("description", {}).get("content")
@@ -274,15 +320,14 @@ class Source(WikiRateEntity):
 
 class SourceItem(WikiRateEntity):
     __slots__ = (
-        "id", "name", "title", "description", "url", "original_source", "file_url", "year", "metrics", "companies",
-        "report_type", "created_at", "updated_at", "raw")
+        "id", "name", "title", "url", "original_source", "file_url", "year", "report_type", "raw")
 
     def __init__(self, data):
         self.raw = data
         if data.get("type") != 'Source':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data.get("name")
         self.title = data.get("title")
         self.file_url = data.get("file")
@@ -302,15 +347,16 @@ class Answer(WikiRateEntity):
         if data["type"]["id"] != 43678:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.metric = data["metric"]
         self.company = data["company"]
         self.value = data.get("value")
         self.year = data.get("year")
         self.comments = data.get("comments")
         self.sources = []
-        for s in data.get("sources", []):
-            self.sources.append(s.get("name"))
+        if not data.get("sources").__str__().__contains__("Error rendering:"):
+            for s in data.get("sources", []):
+                self.sources.append(SourceItem(s))
         self.checked_by = data.get("checked_by").get("content")
         self.check_requested = data.get("checked_by").get("check_requested")
         self.url = data.get("html_url")
@@ -326,7 +372,7 @@ class AnswerItem(WikiRateEntity):
         if data["type"] != 'Answer':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.metric = data["metric"]
         self.company = data["company"]
         self.value = data.get("value")
@@ -349,7 +395,7 @@ class RelationshipAnswer(WikiRateEntity):
         if data["type"]["id"] != 2534606:
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         fields = data.get("name").split("+")
         self.metric = fields[0] + "+" + fields[1]
         self.value = data.get("value")
@@ -371,15 +417,15 @@ class RelationshipAnswer(WikiRateEntity):
 class RelationshipAnswerItem(WikiRateEntity):
     __slots__ = (
         "id", "metric", "metric_id", "value", "year", "comments", "sources",
-        "subject_company_name", "object_company_name", "subject_company_id", "object_company_id"
-                                                                             "url", "raw")
+        "subject_company_name", "object_company_name", "subject_company_id", "object_company_id",
+        "url", "raw")
 
     def __init__(self, data):
         self.raw = data
         if data["type"] != 'Relationship Answer':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         fields = data.get("name").split("+")
         self.metric = fields[0] + "+" + fields[1]
         self.metric_id = data.get("metric_id")
@@ -396,7 +442,7 @@ class RelationshipAnswerItem(WikiRateEntity):
         self.url = data.get("url").replace(".json", "")
 
 
-class Region(WikiRateEntity):
+class RegionItem(WikiRateEntity):
     __slots__ = (
         "id", "name", "url", "raw")
 
@@ -405,6 +451,23 @@ class Region(WikiRateEntity):
         if data["type"] != 'Region':
             raise WikiRate4PyException('Invalid type of entity')
 
-        self.id = int(data["id"])
+        self.id = data.get("id")
         self.name = data.get("name")
         self.url = data.get("url").replace(".json", "")
+
+
+class Region(WikiRateEntity):
+    __slots__ = (
+        "id", "name", "url", "oc_jurisdiction_key", "region", "country", "raw")
+
+    def __init__(self, data):
+        self.raw = data
+        if data["type"]["id"] != 7044738:
+            raise WikiRate4PyException('Invalid type of entity')
+
+        self.id = data.get("id")
+        self.name = data.get("name")
+        self.url = data.get("url").replace(".json", "")
+        self.oc_jurisdiction_key = data.get("items", [])[1].get("content")
+        self.country = data.get("items", [])[3].get("content")
+        self.region = data.get("items", [])[2].get("content")
